timeintervaltools.calculate_min_mean_and_max_durations_of_intervals
===================================================================

.. autofunction:: abjad.tools.timeintervaltools.calculate_min_mean_and_max_durations_of_intervals.calculate_min_mean_and_max_durations_of_intervals
